#!/usr/bin/env python
from __future__ import print_function

import os
import sys
import json
import jsonschema

def load(file_path):
    return json.load(open(file_path))

if __name__ == '__main__':
    if len(sys.argv) != 3:
        raise SystemExit('Usage: validate.py schema file')
    command, schema, path = sys.argv
    schema_path = os.path.dirname(os.path.realpath(schema))
    resolver = jsonschema.RefResolver('file://{0}/'.format(schema_path), None)

    try:
        jsonschema.validate(load(path), load(schema), resolver=resolver)
        print("Validation successful.")
    except:
        validator = jsonschema.Draft4Validator(load(schema), resolver=resolver)
        for number, error in enumerate(sorted(
                validator.iter_errors(load(path))), 1):
            sys.stderr.write("\n{0} Validation Error {1} {0}\n\n{2}\n".format(
                "=" * 30, number, error))
        print("Validation failed.")
        raise SystemExit(1)
